/*
 * ResourcePool.cs - The resource pool class
 *
 * Copyright (C) 2003  Peter Minten
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */ 

namespace DotGNU_TCG
{
	using System.Collections;
	
	//A resource pool is simply a kind of resource hash
	//it's restricted however
	class ResourcePool
	{
		private HashTable values;
		
		//Construct an empty ResourcePool
		public ResourcePool() : this(0,0,0,0,0) {}
		
		//Construct a ResourcePool with the given resource levels
		public ResourcePool(int energy, int matter, int life, int psy,
							int mana)
		{
			values = new HashTable();
			values[Resource.Energy] = energy;
			values[Resource.Matter] = matter;
			values[Resource.Life] = life;
			values[Resource.Psy] = psy;
			values[Resource.Mana] = mana;
		}
		
		//Get/set a resource
		public uint this[Resource res]
		{
			get
			{
				return values[res];
			}
			set
			{
				//We don't need explicit range checks,
				//since all values of uint are allowed.
				values[res] = value;
			}
		}
		
		//Add resources
		public void Add(Resource res, int amount)
		{
			this[res] = this[res] + amount;
		}
		
		//Remove resources
		public void Remove(Resource resource, int amount)
		{
			this[res] = this[res] - amount;			
		}
	};
};